{
Copyright (C) 2000, 2001 Free Software Foundation, Inc.

Author: Eike Lange <eike.lange@uni-essen.de>

This unit implements a set of Funktions for accessing 
MySql. 

This library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation, version 2.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.

You should have received a copy of the GNU Library General Public License
along with this library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA.
}

{
  ==============================
	PLEASE READ THE README
  ==============================
}

{$gnu-pascal,I-}
{$if __GPC_RELEASE__ < 20030323}
{$error This unit requires at least GPC Version 2003-03-23.}
{$endif}

unit MySQL;

interface

const
  MaxVarSize = MaxInt div 8;

const 
	{ Error-Numbers from errmsg.h }
	CR_MIN_ERROR = 2000;
	CR_MAX_ERROR = 2999;
	CLIENT_ERRMAP = 2;
	CR_UNKNOWN_ERROR = 2000;
	CR_SOCKET_CREATE_ERROR = 2001;
	CR_CONNECTION_ERROR = 2002;
	CR_CONN_HOST_ERROR = 2003;
	CR_IPSOCK_ERROR = 2004;
	CR_UNKNOWN_HOST = 2005;
	CR_SERVER_GONE_ERROR = 2006;
	CR_VERSION_ERROR = 2007;
	CR_OUT_OF_MEMORY = 2008;
	CR_WRONG_HOST_INFO = 2009;
	CR_LOCALHOST_CONNECTION = 2010;
	CR_TCP_CONNECTION = 2011;
	CR_SERVER_HANDSHAKE_ERR = 2012;
	CR_SERVER_LOST = 2013;
	CR_COMMANDS_OUT_OF_SYNC = 2014;
	CR_NAMEDPIPE_CONNECTION = 2015;
	CR_NAMEDPIPEWAIT_ERROR = 2016;
	CR_NAMEDPIPEOPEN_ERROR = 2017;
	CR_NAMEDPIPESETSTATE_ERROR = 2018;
	
	ER_HASHCHK = 1000;
	ER_NISAMCHK = 1001;
	ER_NO = 1002;
	ER_YES = 1003;
	ER_CANT_CREATE_FILE = 1004;
	ER_CANT_CREATE_TABLE = 1005;
	ER_CANT_CREATE_DB = 1006;
	ER_DB_CREATE_EXISTS = 1007;
	ER_DB_DROP_EXISTS = 1008;
	ER_DB_DROP_DELETE = 1009;
	ER_DB_DROP_RMDIR = 1010;
	ER_CANT_DELETE_FILE = 1011;
	ER_CANT_FIND_SYSTEM_REC = 1012;
	ER_CANT_GET_STAT = 1013;
	ER_CANT_GET_WD = 1014;
	ER_CANT_LOCK = 1015;
	ER_CANT_OPEN_FILE = 1016;
	ER_FILE_NOT_FOUND = 1017;
	ER_CANT_READ_DIR = 1018;
	ER_CANT_SET_WD = 1019;
	ER_CHECKREAD = 1020;
	ER_DISK_FULL = 1021;
	ER_DUP_KEY = 1022;
	ER_ERROR_ON_CLOSE = 1023;
	ER_ERROR_ON_READ = 1024;
	ER_ERROR_ON_RENAME = 1025;
	ER_ERROR_ON_WRITE = 1026;
	ER_FILE_USED = 1027;
	ER_FILSORT_ABORT = 1028;
	ER_FORM_NOT_FOUND = 1029;
	ER_GET_ERRNO = 1030;
	ER_ILLEGAL_HA = 1031;
	ER_KEY_NOT_FOUND = 1032;
	ER_NOT_FORM_FILE = 1033;
	ER_NOT_KEYFILE = 1034;
	ER_OLD_KEYFILE = 1035;
	ER_OPEN_AS_READONLY = 1036;
	ER_OUTOFMEMORY = 1037;
	ER_OUT_OF_SORTMEMORY = 1038;
	ER_UNEXPECTED_EOF = 1039;
	ER_CON_COUNT_ERROR = 1040;
	ER_OUT_OF_RESOURCES = 1041;
	ER_BAD_HOST_ERROR = 1042;
	ER_HANDSHAKE_ERROR = 1043;
	ER_DBACCESS_DENIED_ERROR = 1044;
	ER_ACCESS_DENIED_ERROR = 1045;
	ER_NO_DB_ERROR = 1046;
	ER_UNKNOWN_COM_ERROR = 1047;
	ER_BAD_NULL_ERROR = 1048;
	ER_BAD_DB_ERROR = 1049;
	ER_TABLE_EXISTS_ERROR = 1050;
	ER_BAD_TABLE_ERROR = 1051;
	ER_NON_UNIQ_ERROR = 1052;
	ER_SERVER_SHUTDOWN = 1053;
	ER_BAD_FIELD_ERROR = 1054;
	ER_WRONG_FIELD_WITH_GROUP = 1055;
	ER_WRONG_GROUP_FIELD = 1056;
	ER_WRONG_SUM_SELECT = 1057;
	ER_WRONG_VALUE_COUNT = 1058;
	ER_TOO_LONG_IDENT = 1059;
	ER_DUP_FIELDNAME = 1060;
	ER_DUP_KEYNAME = 1061;
	ER_DUP_ENTRY = 1062;
	ER_WRONG_FIELD_SPEC = 1063;
	ER_PARSE_ERROR = 1064;
	ER_EMPTY_QUERY = 1065;
	ER_NONUNIQ_TABLE = 1066;
	ER_INVALID_DEFAULT = 1067;
	ER_MULTIPLE_PRI_KEY = 1068;
	ER_TOO_MANY_KEYS = 1069;
	ER_TOO_MANY_KEY_PARTS = 1070;
	ER_TOO_LONG_KEY = 1071;
	ER_KEY_COLUMN_DOES_NOT_EXITS = 1072;
	ER_BLOB_USED_AS_KEY = 1073;
	ER_TOO_BIG_FIELDLENGTH = 1074;
	ER_WRONG_AUTO_KEY = 1075;
	ER_READY = 1076;
	ER_NORMAL_SHUTDOWN = 1077;
	ER_GOT_SIGNAL = 1078;
	ER_SHUTDOWN_COMPLETE = 1079;
	ER_FORCING_CLOSE = 1080;
	ER_IPSOCK_ERROR = 1081;
	ER_NO_SUCH_INDEX = 1082;
	ER_WRONG_FIELD_TERMINATORS = 1083;
	ER_BLOBS_AND_NO_TERMINATED = 1084;
	ER_TEXTFILE_NOT_READABLE = 1085;
	ER_FILE_EXISTS_ERROR = 1086;
	ER_LOAD_INFO = 1087;
	ER_ALTER_INFO = 1088;
	ER_WRONG_SUB_KEY = 1089;
	ER_CANT_REMOVE_ALL_FIELDS = 1090;
	ER_CANT_DROP_FIELD_OR_KEY = 1091;
	ER_INSERT_INFO = 1092;
	ER_INSERT_TABLE_USED = 1093;
	ER_NO_SUCH_THREAD = 1094;
	ER_KILL_DENIED_ERROR = 1095;
	ER_NO_TABLES_USED = 1096;
	ER_TOO_BIG_SET = 1097;
	ER_NO_UNIQUE_LOGFILE = 1098;
	ER_TABLE_NOT_LOCKED_FOR_WRITE = 1099;
	ER_TABLE_NOT_LOCKED = 1100;
	ER_BLOB_CANT_HAVE_DEFAULT = 1101;
	ER_WRONG_DB_NAME = 1102;
	ER_WRONG_TABLE_NAME = 1103;
	ER_TOO_BIG_SELECT = 1104;
	ER_UNKNOWN_ERROR = 1105;
	ER_UNKNOWN_PROCEDURE = 1106;
	ER_WRONG_PARAMCOUNT_TO_PROCEDURE = 1107;
	ER_WRONG_PARAMETERS_TO_PROCEDURE = 1108;
	ER_UNKNOWN_TABLE = 1109;
	ER_FIELD_SPECIFIED_TWICE = 1110;
	ER_INVALID_GROUP_FUNC_USE = 1111;
	ER_UNSUPPORTED_EXTENSION = 1112;
	ER_TABLE_MUST_HAVE_COLUMNS = 1113;
	ER_RECORD_FILE_FULL = 1114;
	ER_UNKNOWN_CHARACTER_SET = 1115;
	ER_TOO_MANY_TABLES = 1116;
	ER_TOO_MANY_FIELDS = 1117;
	ER_TOO_BIG_ROWSIZE = 1118;
	ER_STACK_OVERRUN = 1119;
	ER_WRONG_OUTER_JOIN = 1120;
	ER_NULL_COLUMN_IN_INDEX = 1121;
	ER_CANT_FIND_UDF = 1122;
	ER_CANT_INITIALIZE_UDF = 1123;
	ER_UDF_NO_PATHS = 1124;
	ER_UDF_EXISTS = 1125;
	ER_CANT_OPEN_LIBRARY = 1126;
	ER_CANT_FIND_DL_ENTRY = 1127;
	ER_FUNCTION_NOT_DEFINED = 1128;
	ER_HOST_IS_BLOCKED = 1129;
	ER_HOST_NOT_PRIVILEGED = 1130;
	ER_PASSWORD_ANONYMOUS_USER = 1131;
	ER_PASSWORD_NOT_ALLOWED = 1132;
	ER_PASSWORD_NO_MATCH = 1133;
	ER_UPDATE_INFO = 1134;
	ER_CANT_CREATE_THREAD = 1135;
	ER_WRONG_VALUE_COUNT_ON_ROW = 1136;
	ER_CANT_REOPEN_TABLE = 1137;
	ER_INVALID_USE_OF_NULL = 1138;
	ER_REGEXP_ERROR = 1139;
	ER_MIX_OF_GROUP_FUNC_AND_FIELDS = 1140;
	ER_NONEXISTING_GRANT = 1141;
	ER_TABLEACCESS_DENIED_ERROR = 1142;
	ER_COLUMNACCESS_DENIED_ERROR = 1143;
	ER_ILLEGAL_GRANT_FOR_TABLE = 1144;
	ER_GRANT_WRONG_HOST_OR_USER = 1145;
	ER_NO_SUCH_TABLE = 1146;
	ER_NONEXISTING_TABLE_GRANT = 1147;
	ER_NOT_ALLOWED_COMMAND = 1148;
	ER_SYNTAX_ERROR = 1149;
	ER_DELAYED_CANT_CHANGE_LOCK = 1150;
	ER_TOO_MANY_DELAYED_THREADS = 1151;
	ER_ABORTING_CONNECTION = 1152;
	ER_NET_PACKET_TOO_LARGE = 1153;
	ER_NET_READ_ERROR_FROM_PIPE = 1154;
	ER_NET_FCNTL_ERROR = 1155;
	ER_NET_PACKETS_OUT_OF_ORDER = 1156;
	ER_NET_UNCOMPRESS_ERROR = 1157;
	ER_NET_READ_ERROR = 1158;
	ER_NET_READ_INTERRUPTED = 1159;
	ER_NET_ERROR_ON_WRITE = 1160;
	ER_NET_WRITE_INTERRUPTED = 1161;
	ER_ERROR_MESSAGES = 162;

{ field_types from mysql_com.h }
	FIELD_TYPE_DECIMAL			= 0;
	FIELD_TYPE_TINY					= 1;
	FIELD_TYPE_SHORT				= 2;
	FIELD_TYPE_LONG					= 3;
	FIELD_TYPE_FLOAT				= 4;
	FIELD_TYPE_DOUBLE				= 5;
	FIELD_TYPE_NULL					= 6;
	FIELD_TYPE_TIMESTAMP		= 7;
	FIELD_TYPE_LONGLONG			= 8;
	FIELD_TYPE_INT24				= 9;
	FIELD_TYPE_DATE					= 10;
  FIELD_TYPE_TIME					= 11;
	FIELD_TYPE_DATETIME			= 12;
	FIELD_TYPE_YEAR					= 13;
	FIELD_TYPE_NEWDATE			= 14;
	FIELD_TYPE_ENUM					= 247;
	FIELD_TYPE_SET					= 248;
	FIELD_TYPE_TINY_BLOB		= 249;
	FIELD_TYPE_MEDIUM_BLOB	= 250;
	FIELD_TYPE_LONG_BLOB		= 251;
	FIELD_TYPE_BLOB					= 252;
 	FIELD_TYPE_VAR_STRING		= 253;
 	FIELD_TYPE_STRING				= 254;

	{ Options from mysql.h for MysqlOptions }
	MYSQL_OPT_CONNECT_TIMEOUT = 0;
	MYSQL_OPT_COMPRESS        = 1;
	MYSQL_OPT_NAMED_PIPE      = 2;
	MYSQL_INIT_COMMAND        = 3;
	MYSQL_READ_DEFAULT_FILE   = 4;
	MYSQL_READ_DEFAULT_GROUP  = 5;
	MYSQL_SET_CHARSET_DIR     = 6;
	MYSQL_SET_CHARSET_NAME    = 7;

type
  PMySQL = Pointer;						{ Pointer to MySQL-Structure }
  PMySQLRes = Pointer;				{ Pointer to MySQL_RES-Structure }
  ShortString = String (32);
  NormalString = String (255);
  CMySQLRow = array [0 .. MaxVarSize div SizeOf(CString) - 1] of CString;
  MySQLRow = ^CMySQLRow;

  PMySQLField=^MySQLField;
  MySQLField=record
	  Name, Table, Def: CString;
  	{ Not the same enum-Numbers like C !!! so I think, it would be OK,
	  	to change the Name from "type" to 'typ'
		  because "type" is a keyword in Pascal
  	}
	  Typ: Integer;  { See FIELD_TYPE_* - Constants above }
  	Length, MaxLength, Flags, Decimals: Cardinal
  end;

MySQLFieldArray = array [0 .. High (ShortCard) div SizeOf(MySQLField) - 1] of MySQLField;
MySQLFieldOffset = Cardinal;

PFLA = ^FLA;
FLA = array [0 .. MaxVarSize div SizeOf(MedCard) - 1] of MedCard;

{
Its just a pointer, because the contents are given by MySQLFetchRow,
its just for MySQLRowSeek and MySQLRowTell
}
MySQLRowOffset = Pointer;


{ --------------------------------------------------------}
{ Functions }
{ --------------------------------------------------------}

{ Gives out the number of affected rows, you must call something
like MySQLStoreResult, if you use a SELECT-query}
function MySQLAffectedRows(MySQLHandle: PMySQL): LongInt;
external name '_p_mysql_affected_rows';

{ Changes the user and database of a given connection. (See query1.pas) }
function MySQLChangeUser(MySQLHandle: PMySQL; User, Password, Database: NormalString): Boolean;

{ returns the Name of the character-set }
function MySQLCharacterSetName(MySQLHandle: PMySQL): NormalString;

procedure MySQLClose(MySQLHandle: PMySQL);
external name '_p_mysql_close';

{ Creates a MySQL-Database }
function MySQLCreateDb(MySQLHandle: PMySQL; DatabaseName: CString): Boolean;

{ Offset is from 0 to NumRows-1, else returns memory-error }
procedure MySQLDataSeek(MySQLHandle: PMySQL; Offset: Cardinal);
external name '_p_mysql_data_seek';

{ You may need FredFish: "Debug Library" to use this Procedure. See
chapters G1/G2 (Debugging MySQL client and server) in MySQL
Reference Manual for Details (Version 3.23.42) }
procedure MySQLDebug(Debug: CString);
external name '_p_mysql_debug';

function MySQLDropDb(MySQLHandle: PMySQL; DatabaseName: CString): Boolean;

function MySQLDumpDebugInfo(MySQLHandle: PMySQL): Boolean;

function MySQLErrNo(MySQLHandle: PMySQL): Cardinal;
external name '_p_mysql_errno';

function MySQLError(MySQLHandle: PMySQL): NormalString;

function MySQLEscapeString(ToString: CString; FromString: CString; Length: Cardinal): Cardinal;
external name '_p_mysql_escape_string';

function MySQLFetchField(MySQLRes: PMySQLRes): PMySQLField;
external name '_p_mysql_fetch_field';

function MySQLFetchFieldDirect(MySQLRes: PMySQLRes; FieldNr: Cardinal): PMySQLField;
external name '_p_mysql_fetch_field_direct';

{ Fetches all fields and saves them in MySQLFieldArray. (See FetchFields.pas) }
function MySQLFetchFields(MySQLRes: PMySQLRes): MySQLFieldArray;

{ Be sure  to call MySQLFetchLengths AFTER MySQLFetchRow }
function MySQLFetchLengths(MySQLRes: PMySQLRes): PFLA;
external name '_p_mysql_fetch_lengths';

function MySQLFetchRow(MySQLRes: PMySQLRes): MySQLRow;
external name '_p_mysql_fetch_row';

{ returns the number of columns for the last query }
function MySQLFieldCount(MySQLHandle: PMySQL): Cardinal;
external name '_p_mysql_field_count';

function MySQLFieldSeek(MySQLRes: PMySQLRes; Offset: MySQLFieldOffset): MySQLFieldOffset;
external name '_p_mysql_field_seek';

function MySQLFieldTell(MySQLRes: PMySQLRes): MySQLFieldOffset;
external name '_p_mysql_field_tell';

procedure MySQLFreeResult(MySQLRes: PMySQLRes);
external name '_p_mysql_free_result';

function MySQLGetClientInfo: NormalString;

function MySQLGetHostInfo(MySQLHandle: PMySQL): NormalString;

function MySQLGetProtoInfo(MySQLHandle: PMySQL): Cardinal;
external name '_p_mysql_get_proto_info';

{ Prints Out Version Information about mysql }
function MySQLGetServerInfo(MySQLHandle: PMySQL): ShortString; 

function MySQLInfo(MySQLHandle: PMySQL): NormalString;
{ Initializes MySQL-Api. Must be first API-Function }

function MySQLInit(MySQLHandle:PMySQL): PMySQL; 
external name '_p_mysql_init';

{ Returns the ID for an auto_increment value after SQL-INSERT }
function MySQLInsertId(MySQLHandle:PMySQL): LongInt;
external name '_p_mysql_insert_id';

{ Kills the Server, Returns True on success }
function MySQLKill(MySQLHandle: PMySQL; PID: Integer): Boolean;

{ Returns a Handle points to all the DBs which MySQL handles }
function MySQLListDbs(MySQLHandle: PMySQL; Wild: CString): PMySQLRes;
external name '_p_mysql_list_dbs';

{ Returns a Handle points to all the fields of a given table }
function MySQLListFields(MySQLHandle: PMySQL; Table: CString; Wild: CString): PMySQLRes;
external name '_p_mysql_list_fields';

function MySQLListProcesses(MySQLHandle: PMySQL): PMySQLRes;
external name '_p_mysql_list_processes';

{ Returns a Handle points to all the DBs which MySQL handles }
function MySQLListTables(MySQLHandle: PMySQL; Wild: CString): PMySQLRes;
external name '_p_mysql_list_tables';

{ Gives out the number of Fiels }
function MySQLNumFields(MySQLRes: PMySQLRes): Cardinal;
external name '_p_mysql_num_fields';

{ Gives out the number of affected rows }
function MySQLNumRows(MySQLRes: PMySQLRes): LongInt;
external name '_p_mysql_num_rows';

{ Sets extra-connect-options. option is one of the following:
MYSQL_OPT_CONNECT_TIMEOUT, MYSQL_OPT_COMPRESS, MYSQL_OPT_NameD_PIPE,
MYSQL_INIT_COMMAND, MYSQL_READ_DEFAULT_FILE, MYSQL_READ_DEFAULT_GROUP,
MYSQL_SET_CHARSET_DIR, MYSQL_SET_CHARSET_Name}
function MySQLOptions(MySQLHandle: PMySQL; Option: Integer; Arg: CString): Boolean;

{ Returns True, if Server is alive }
function MySQLPing(MySQLHandle: PMySQL): Boolean;

{ Executes a Query like "SELECT * FROM test", returns True on success}
function MySQLQuery(MySQLHandle: PMySQL; aQuery: CString): Boolean;

{ Connects to mysql. You *must* call MySQLInit first! You need at least
the Name of the Database }
function MySQLRealConnect(MySQLHandle: PMySQL; Host: CString;
  User: CString; Passwd: CString; Db: CString; Port: Cardinal;
  Socket: CString; ClientFlag: Cardinal): PMySQL;
external name '_p_mysql_real_connect';

{ Connects to mysql. You *must* call MySQLInit first! You need at least
the Name of the Database }
function MySQLRealConnect2(MySQLHandle: PMySQL; Host: CString;
  User: CString; Passwd: CString; Db: CString): PMySQL;
external name '_p_mysql_real_connect2';

function MySQLRealEscapeString(MySQLHandle: PMySQL; ToString: CString; FromString: CString; Length: Cardinal): Cardinal;
external name '_p_mysql_real_escape_string';

function MySQLRealQuery(MySQLHandle: PMySQL; aQuery: CString; aLength: Cardinal):Boolean;

function MySQLRowSeek(MySQLRes: PMySQLRes; Offset: MySQLRowOffset): MySQLRowOffset;
external name '_p_mysql_row_seek';

function MySQLRowTell(MySQLRes: PMySQLRes): MySQLRowOffset;
external name '_p_mysql_row_tell';

function MySQLSelectDb(MySQLHandle: PMySQL; Database: CString): Boolean;

function MySQLShutdown(MySQLHandle: PMySQL): Boolean;

function MySQLStat(MySQLHandle: PMySQL): NormalString;

function MySQLStoreResult(MySQLHandle: PMySQL): PMySQLRes;
external name '_p_mysql_store_result';

function MySQLThreadId(MySQLHandle: PMySQL): Cardinal;
external name '_p_mysql_thread_id';

function MySQLUseResult(MySQLHandle: PMySQL): PMySQLRes;
external name '_p_mysql_use_result';


{ ================================================================== }

implementation
{$L mysqlclient,mysqlc.c}
{ Define this if your version of the MySql library requires -lz. }
{.$L z}

function CMySQLChangeUser(MySQLHandle: PMySQL; u, p, d: CString): Byte;
external name '_p_mysql_change_user';

function CMySQLCharacterSetName(MySQLHandle: PMySQL): CString;
external name '_p_mysql_character_set_name';

{ The original MySQL_Create_Db - C-Function return 0 on success. 
Pascal Style is True/False, I think }
function CMySQLCreateDb(MySQLRes: PMySQLRes; DatabaseName: CString): Integer;
external name '_p_mysql_create_db';

{ The original MySQL_Drop_Db - C-function return 0 on success. 
Pascal Style is True/False, I think }
function CMySQLDropDb(MySQLRes: PMySQLRes; DatabaseName: CString): Integer;
external name '_p_mysql_drop_db';

{ The original MySQL_Dump_debug_info- C-function return 0 on success. 
Pascal Style is True/False, I think }
function CMySQLDumpDebugInfo(MySQLRes: PMySQLRes): Integer;
external name '_p_mysql_dump_debug_info';

{ I don't want to return a CString so ...}
function CMySQLError(MySQLHandle: PMySQL): CString;
external name '_p_mysql_error';

{ I don't want to return a CString so ...}
function CMySQLGetClientInfo: CString; 
external name '_p_mysql_get_client_info';

{ I don't want to return a CString so ...}
function CMySQLGetHostInfo(MySQLHandle: PMySQL): CString; 
external name '_p_mysql_get_host_info';

{ I don't want to return a CString so ...}
function CMySQLGetServerInfo(MySQLHandle: PMySQL): CString; 
external name '_p_mysql_get_server_info';

function CMySQLInfo(MySQLHandle: PMySQL): CString;
external name '_p_mysql_info';

function CMySQLKill(MySQLHandle: PMySQL; PID: Integer): Integer;
external name '_p_mysql_kill';

function CMySQLOptions(MySQLHandle: PMySQL; Opt: Integer; Arg: CString): Integer;
external name '_p_mysql_options';

function CMySQLPing(MySQLHandle: PMySQL): Integer;
external name '_p_mysql_ping';

function CMySQLQuery(MySQLHandle: PMySQL; aQuery: CString): Integer;
external name '_p_mysql_query';

function CMySQLRealQuery(MySQLHandle: PMySQL; aQuery: CString; aLength: Cardinal):Integer;
external name '_p_mysql_real_query';

function CMySQLSelectDb(MySQLHandle: PMySQL; Db: CString): Integer;
external name '_p_mysql_select_db';

function CMySQLShutdown(MySQLHandle: PMySQL): Integer;
external name '_p_mysql_shutdown';

function CMySQLStat(MySQLHandle: PMySQL): CString;
external name '_p_mysql_stat';


function MySQLChangeUser(MySQLHandle: PMySQL; User, Password, Database: NormalString): Boolean;
begin
	MySQLChangeUser := CMySQLChangeUser(MySQLHandle, User, Password, Database) = 0
end;

function MySQLCharacterSetName(MySQLHandle: PMySQL): NormalString;
begin
  MySQLCharacterSetName := CString2String (CMySQLCharacterSetName(MySQLHandle))
end;

function MySQLCreateDb(MySQLHandle: PMySQL; DatabaseName: CString): Boolean;
begin
	MySQLCreateDb := CMySQLCreateDb(MySQLHandle, DatabaseName) = 0
end;

function MySQLDropDb(MySQLHandle: PMySQL; DatabaseName: CString): Boolean;
begin
	MySQLDropDb := CMySQLDropDb(MySQLHandle, DatabaseName) = 0 
end;

function MySQLDumpDebugInfo(MySQLHandle: PMySQL): Boolean;
begin
	MySQLDumpDebugInfo := CMySQLDumpDebugInfo(MySQLHandle) = 0
end;

function MySQLError(MySQLHandle: PMySQL): NormalString;
begin
	MySQLError:=CString2String(CMySQLError(MySQLHandle))
end;

function MySQLFetchFields(MySQLRes: PMySQLRes) = fa: MySQLFieldArray;
var
	i: Cardinal;
begin
	for i := 0 To (MySQLNumFields(MySQLRes) - 1) do
		fa[i] := MySQLFetchField(MySQLRes)^;
end;

function MySQLGetClientInfo: NormalString;
begin
	MySQLGetClientInfo:=CString2String(CMySQLGetClientInfo);
end;

function MySQLGetHostInfo(MySQLHandle: PMySQL): NormalString;
begin
	MySQLGetHostInfo:=CString2String(CMySQLGetHostInfo(MySQLHandle));
end;

function MySQLGetServerInfo(MySQLHandle: PMySQL): ShortString; 
begin
	MySQLGetServerInfo:=CString2String(CMySQLGetServerInfo(MySQLHandle))
end;

function MySQLInfo(MySQLHandle: PMySQL): NormalString;
begin
	MySQLInfo:=CString2String(CMySQLInfo(MySQLHandle));
end;

function MySQLKill(MySQLHandle: PMySQL; PID: Integer): Boolean;
begin
	MySQLKill := CMySQLKill(MySQLHandle, PID) = 0
end;

function MySQLOptions(MySQLHandle: PMySQL; Option: Integer; Arg: CString): Boolean;
begin
	MySQLOptions := CMySQLOptions(MySQLHandle, Option, Arg) = 0
end;

function MySQLPing(MySQLHandle: PMySQL): Boolean;
begin
	MySQLPing := CMySQLPing(MySQLHandle) = 0
end;

function MySQLQuery(MySQLHandle: PMySQL; aQuery: CString): Boolean;
begin	
	MySQLQuery := CMySQLQuery(MySQLHandle, aQuery) = 0
end;

function MySQLRealQuery(MySQLHandle: PMySQL; aQuery: CString; aLength: Cardinal):Boolean;
begin
	MySQLRealQuery := CMySQLRealQuery(MySQLHandle, aQuery, aLength) = 0
end;

function MySQLSelectDb(MySQLHandle: PMySQL; Database: CString): Boolean;
begin
	MySQLSelectDb := CMySQLSelectDb(MySQLHandle, Database) = 0
end;

function MySQLShutdown(MySQLHandle: PMySQL): Boolean;
begin
	MySQLShutdown := CMySQLShutdown(MySQLHandle) = 0
end;

function MySQLStat(MySQLHandle: PMySQL): NormalString;
begin
	MySQLStat:=CString2String(CMySQLStat(MySQLHandle));
end;

end.
